If you would like to contribute to the development of OpenStack,
you must follow the steps in the "If you're a developer, start here"
section of `How To Contribute Guide <https://wiki.openstack.org/wiki/How_To_Contribute>`_.

Once those steps have been completed, changes to OpenStack
should be submitted for review via the Gerrit tool, following
the documented `Development Workflow <https://docs.openstack.org/infra/manual/developers.html>`_.

Pull requests submitted through GitHub will be ignored.

Bugs should be filed on `TripleO at Launchpad <https://bugs.launchpad.net/tripleo>`_
not GitHub.
